.highlight-chroma{background-color:#f8f8f8}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#dfdfdf}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd,.highlight-chroma .highlight-kn{color:#a2f;font-weight:700}.highlight-chroma .highlight-kp{color:#a2f}.highlight-chroma .highlight-kr{color:#a2f;font-weight:700}.highlight-chroma .highlight-kt{color:#0b0;font-weight:700}.highlight-chroma .highlight-na{color:#b44}.highlight-chroma .highlight-nb{color:#a2f}.highlight-chroma .highlight-nc{color:#00f}.highlight-chroma .highlight-no{color:#800}.highlight-chroma .highlight-nd{color:#a2f}.highlight-chroma .highlight-ni{color:#999;font-weight:700}.highlight-chroma .highlight-ne{color:#d2413a;font-weight:700}.highlight-chroma .highlight-nf{color:#00a000}.highlight-chroma .highlight-nl{color:#a0a000}.highlight-chroma .highlight-nn{color:#00f;font-weight:700}.highlight-chroma .highlight-nt{color:green;font-weight:700}.highlight-chroma .highlight-nv{color:#b8860b}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc{color:#b44}.highlight-chroma .highlight-sd{color:#b44;font-style:italic}.highlight-chroma .highlight-s2{color:#b44}.highlight-chroma .highlight-se{color:#b62;font-weight:700}.highlight-chroma .highlight-sh{color:#b44}.highlight-chroma .highlight-si{color:#b68;font-weight:700}.highlight-chroma .highlight-sx{color:green}.highlight-chroma .highlight-sr{color:#b68}.highlight-chroma .highlight-s1{color:#b44}.highlight-chroma .highlight-ss{color:#b8860b}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo,.highlight-chroma .highlight-o{color:#666}.highlight-chroma .highlight-ow{color:#a2f;font-weight:700}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm{color:#080;font-style:italic}.highlight-chroma .highlight-cs{color:#080;font-weight:700}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:#080}.highlight-chroma .highlight-gd{color:#a00000}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gr{color:red}.highlight-chroma .highlight-gh{color:navy;font-weight:700}.highlight-chroma .highlight-gi{color:#00a000}.highlight-chroma .highlight-go{color:#888}.highlight-chroma .highlight-gp{color:navy;font-weight:700}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:purple;font-weight:700}.highlight-chroma .highlight-gt{color:#04d}.highlight-chroma .highlight-gl{text-decoration:underline}.highlight-chroma .highlight-w{color:#bbb}.hljs{display:block;overflow-x:auto;padding:.5em;color:#383a42;background:#fafafa}.hljs-comment,.hljs-quote{color:#a0a1a7;font-style:italic}.hljs-doctag,.hljs-formula,.hljs-keyword{color:#a626a4}.hljs-deletion,.hljs-name,.hljs-section,.hljs-selector-tag,.hljs-subst{color:#e45649}.hljs-literal{color:#0184bb}.hljs-addition,.hljs-attribute,.hljs-meta-string,.hljs-regexp,.hljs-string{color:#50a14f}.hljs-built_in,.hljs-class .hljs-title{color:#c18401}.hljs-attr,.hljs-number,.hljs-selector-attr,.hljs-selector-class,.hljs-selector-pseudo,.hljs-template-variable,.hljs-type,.hljs-variable{color:#986801}.hljs-bullet,.hljs-link,.hljs-meta,.hljs-selector-id,.hljs-symbol,.hljs-title{color:#4078f2}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}.hljs-link{text-decoration:underline}