.highlight-chroma{color:#4d4d4d;background-color:#fff}.highlight-chroma .highlight-err{color:#fff;background-color:#c00}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#e5e5e5}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd,.highlight-chroma .highlight-kn{color:#2c5dcd;font-weight:700}.highlight-chroma .highlight-kp{color:#2c5dcd}.highlight-chroma .highlight-kr{color:#2c5dcd;font-weight:700}.highlight-chroma .highlight-kt{color:#5918bb;font-weight:700}.highlight-chroma .highlight-na{color:#2c5dcd;font-style:italic}.highlight-chroma .highlight-nb{color:#5918bb;font-weight:700}.highlight-chroma .highlight-nc{text-decoration:underline}.highlight-chroma .highlight-no{color:#318495}.highlight-chroma .highlight-nd{color:#ff8000;font-weight:700}.highlight-chroma .highlight-ne,.highlight-chroma .highlight-ni{color:#5918bb;font-weight:700}.highlight-chroma .highlight-nf{color:#ff8000;font-weight:700}.highlight-chroma .highlight-nt{color:#2c5dcd;font-weight:700}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc{color:#0c6}.highlight-chroma .highlight-sd{color:#0c6;font-style:italic}.highlight-chroma .highlight-s2{color:#0c6}.highlight-chroma .highlight-se{color:#c5060b;font-weight:700}.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si{color:#0c6}.highlight-chroma .highlight-sx{color:#318495}.highlight-chroma .highlight-s1,.highlight-chroma .highlight-sr{color:#0c6}.highlight-chroma .highlight-ss{color:#c5060b;font-weight:700}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#5918bb;font-weight:700}.highlight-chroma .highlight-o{color:#2c5dcd}.highlight-chroma .highlight-ow{color:#2c5dcd;font-weight:700}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm{color:#0080ff;font-style:italic}.highlight-chroma .highlight-cs{color:#0080ff;font-weight:700;font-style:italic}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:#0080ff}.highlight-chroma .highlight-gd{background-color:#fcc}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gr{color:red}.highlight-chroma .highlight-gh{color:#2c5dcd;font-weight:700}.highlight-chroma .highlight-gi{background-color:#cfc}.highlight-chroma .highlight-go{color:#aaa}.highlight-chroma .highlight-gp{color:#2c5dcd;font-weight:700}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:#2c5dcd;font-weight:700}.highlight-chroma .highlight-gt{color:#c5060b}.highlight-chroma .highlight-gl{text-decoration:underline}.highlight-chroma .highlight-w{color:#cbcbcb}.hljs{display:block;overflow-x:auto;padding:.5em;color:#000;background:#fff}.hljs-subst,.hljs-title{font-weight:400;color:#000}.hljs-comment,.hljs-quote{color:grey;font-style:italic}.hljs-meta{color:olive}.hljs-tag{background:#efefef}.hljs-keyword,.hljs-literal,.hljs-name,.hljs-section,.hljs-selector-class,.hljs-selector-id,.hljs-selector-tag,.hljs-type{font-weight:700;color:navy}.hljs-attribute,.hljs-link,.hljs-number,.hljs-regexp{font-weight:700;color:#00f}.hljs-link,.hljs-number,.hljs-regexp{font-weight:400}.hljs-string{color:green;font-weight:700}.hljs-bullet,.hljs-formula,.hljs-symbol{color:#000;background:#d0eded;font-style:italic}.hljs-doctag{text-decoration:underline}.hljs-template-variable,.hljs-variable{color:#660e7a}.hljs-addition{background:#baeeba}.hljs-deletion{background:#ffc8bd}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}