.highlight-chroma{background-color:#f6f8fa}.highlight-chroma .highlight-err{color:#a61717;background-color:#e3d2d2}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#e5e5e5}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd,.highlight-chroma .highlight-kn,.highlight-chroma .highlight-kp,.highlight-chroma .highlight-kr{color:#000;font-weight:700}.highlight-chroma .highlight-kt{color:#458;font-weight:700}.highlight-chroma .highlight-na{color:teal}.highlight-chroma .highlight-nb{color:#0086b3}.highlight-chroma .highlight-bp{color:#999}.highlight-chroma .highlight-nc{color:#458;font-weight:700}.highlight-chroma .highlight-no{color:teal}.highlight-chroma .highlight-nd{color:#3c5d5d;font-weight:700}.highlight-chroma .highlight-ni{color:purple}.highlight-chroma .highlight-ne,.highlight-chroma .highlight-nf,.highlight-chroma .highlight-nl{color:#900;font-weight:700}.highlight-chroma .highlight-nn{color:#555}.highlight-chroma .highlight-nt{color:navy}.highlight-chroma .highlight-nv,.highlight-chroma .highlight-vc,.highlight-chroma .highlight-vg,.highlight-chroma .highlight-vi{color:teal}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc,.highlight-chroma .highlight-sd,.highlight-chroma .highlight-se,.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si,.highlight-chroma .highlight-sx{color:#d14}.highlight-chroma .highlight-sr{color:#009926}.highlight-chroma .highlight-s1{color:#d14}.highlight-chroma .highlight-ss{color:#990073}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#099}.highlight-chroma .highlight-o,.highlight-chroma .highlight-ow{color:#000;font-weight:700}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm{color:#998;font-style:italic}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf,.highlight-chroma .highlight-cs{color:#999;font-weight:700;font-style:italic}.highlight-chroma .highlight-gd{color:#000;background-color:#fdd}.highlight-chroma .highlight-ge{color:#000;font-style:italic}.highlight-chroma .highlight-gr{color:#a00}.highlight-chroma .highlight-gh{color:#999}.highlight-chroma .highlight-gi{color:#000;background-color:#dfd}.highlight-chroma .highlight-go{color:#888}.highlight-chroma .highlight-gp{color:#555}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:#aaa}.highlight-chroma .highlight-gt{color:#a00}.highlight-chroma .highlight-gl{text-decoration:underline}.highlight-chroma .highlight-w{color:#bbb}.hljs{display:block;overflow-x:auto;padding:.5em;color:#333;background:#f8f8f8}.hljs-comment,.hljs-quote{color:#998;font-style:italic}.hljs-keyword,.hljs-selector-tag,.hljs-subst{color:#333;font-weight:700}.hljs-literal,.hljs-number,.hljs-tag .hljs-attr,.hljs-template-variable,.hljs-variable{color:teal}.hljs-doctag,.hljs-string{color:#d14}.hljs-section,.hljs-selector-id,.hljs-title{color:#900;font-weight:700}.hljs-subst{font-weight:400}.hljs-class .hljs-title,.hljs-type{color:#458;font-weight:700}.hljs-attribute,.hljs-name,.hljs-tag{color:navy;font-weight:400}.hljs-link,.hljs-regexp{color:#009926}.hljs-bullet,.hljs-symbol{color:#990073}.hljs-built_in,.hljs-builtin-name{color:#0086b3}.hljs-meta{color:#999;font-weight:700}.hljs-deletion{background:#fdd}.hljs-addition{background:#dfd}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}