.highlight-chroma{display:block;padding:16px 32px;color:rgba(0,0,0,.85);font-size:14px;font-family:lucida console,Consolas,Monaco,andale mono,ubuntu mono,monospace;line-height:2;white-space:pre;background:#fff;border:1px solid #e9e9e9;border-radius:2px}.highlight-chroma::selection{text-shadow:none;background:#b3d4fc}.highlight-o{color:#0b8235}.highlight-p{color:#999}.highlight-chroma .highlight-err{color:#a61717;background-color:#e3d2d2}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#363636}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#686868}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd,.highlight-chroma .highlight-kn{color:#6ab825;font-weight:700}.highlight-chroma .highlight-kp{color:#6ab825}.highlight-chroma .highlight-kr{color:#008dff}.highlight-chroma .highlight-kt{color:#6ab825;font-weight:700}.highlight-chroma .highlight-na{color:#bbb}.highlight-chroma .highlight-nb{color:#24909d}.highlight-chroma .highlight-nc{color:#447fcf;text-decoration:underline}.highlight-chroma .highlight-no{color:#40ffff}.highlight-chroma .highlight-nd{color:orange}.highlight-chroma .highlight-ne{color:#bbb}.highlight-chroma .highlight-nf{color:#447fcf}.highlight-chroma .highlight-nn{color:#447fcf;text-decoration:underline}.highlight-chroma .highlight-nt{color:#6ab825;font-weight:700}.highlight-chroma .highlight-nv{color:#40ffff}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc,.highlight-chroma .highlight-sd,.highlight-chroma .highlight-se,.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si{color:#ed9d13}.highlight-chroma .highlight-sx{color:orange}.highlight-chroma .highlight-sr{color:#e90}.highlight-chroma .highlight-s1{color:#0b8235}.highlight-chroma .highlight-ss{color:#ed9d13}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#3677a9}.highlight-chroma .highlight-ow{color:#6ab825;font-weight:700}.highlight-chroma .highlight-c,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm{color:#999;font-style:italic}.highlight-chroma .highlight-c1{color:#708090;font-style:italic}.highlight-chroma .highlight-cs{color:#e50808;background-color:#520000;font-weight:700}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:#cd2828;font-weight:700}.highlight-chroma .highlight-gd{color:#d22323}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gr{color:#d22323}.highlight-chroma .highlight-gh{color:#fff;font-weight:700}.highlight-chroma .highlight-gi{color:#589819}.highlight-chroma .highlight-go{color:#ccc}.highlight-chroma .highlight-gp{color:#aaa}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:#fff;text-decoration:underline}.highlight-chroma .highlight-gt{color:#d22323}.highlight-chroma .highlight-gl{text-decoration:underline}.highlight-chroma .highlight-w{color:#666}.hljs{display:block;padding:16px 32px;color:rgba(0,0,0,.85);font-size:14px;font-family:lucida console,Consolas,Monaco,andale mono,ubuntu mono,monospace;line-height:2;white-space:pre;background:#fff;border:1px solid #e9e9e9;border-radius:2px}.hljs::selection{text-shadow:none;background:#b3d4fc}.hljs-comment,.hljs-quote{color:#708090;font-style:italic}.hljs-doctag,.hljs-formula,.hljs-keyword{color:#008dff}.hljs-deletion,.hljs-name,.hljs-section,.hljs-selector-tag,.hljs-subst{color:#999}.hljs-literal{color:#56b6c2}.hljs-regexp{color:#e90}.hljs-addition,.hljs-attribute,.hljs-meta-string,.hljs-string{color:#0b8235}.hljs-built_in,.hljs-class .hljs-title{color:#e6c07b}.hljs-attr,.hljs-bullet,.hljs-link,.hljs-meta,.hljs-number,.hljs-selector-attr,.hljs-selector-class,.hljs-selector-id,.hljs-selector-pseudo,.hljs-symbol,.hljs-template-variable,.hljs-title,.hljs-type,.hljs-variable{color:#f81d22}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}.hljs-link{text-decoration:underline}