.highlight-chroma{color:#fff;background-color:#111}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#282828}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd,.highlight-chroma .highlight-kn{color:#fb660a;font-weight:700}.highlight-chroma .highlight-kp{color:#fb660a}.highlight-chroma .highlight-kr{color:#fb660a;font-weight:700}.highlight-chroma .highlight-kt{color:#cdcaa9;font-weight:700}.highlight-chroma .highlight-na{color:#ff0086;font-weight:700}.highlight-chroma .highlight-no{color:#0086d2}.highlight-chroma .highlight-nf{color:#ff0086;font-weight:700}.highlight-chroma .highlight-nt{color:#fb660a;font-weight:700}.highlight-chroma .highlight-nv{color:#fb660a}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s,.highlight-chroma .highlight-s1,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc,.highlight-chroma .highlight-sd,.highlight-chroma .highlight-se,.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si,.highlight-chroma .highlight-sr,.highlight-chroma .highlight-ss,.highlight-chroma .highlight-sx{color:#0086d2}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#0086f7;font-weight:700}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm,.highlight-chroma .highlight-cs{color:#080;background-color:#0f140f;font-style:italic}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:#ff0007;background-color:#0f140f;font-weight:700;font-style:italic}.highlight-chroma .highlight-gh{font-weight:700}.highlight-chroma .highlight-go{color:#444;background-color:#222}.highlight-chroma .highlight-gu{font-weight:700}.highlight-chroma .highlight-w{color:#888}.hljs-comment,.hljs-quote{color:#9c9491}.hljs-attribute,.hljs-link,.hljs-name,.hljs-regexp,.hljs-selector-class,.hljs-selector-id,.hljs-tag,.hljs-template-variable,.hljs-variable{color:#f22c40}.hljs-built_in,.hljs-builtin-name,.hljs-literal,.hljs-meta,.hljs-number,.hljs-params,.hljs-type{color:#df5320}.hljs-bullet,.hljs-string,.hljs-symbol{color:#7b9726}.hljs-section,.hljs-title{color:#407ee7}.hljs-keyword,.hljs-selector-tag{color:#6666ea}.hljs{display:block;overflow-x:auto;background:#1b1918;color:#a8a19f;padding:.5em}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}