.highlight-chroma{color:#ccc;background-color:#000}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#191919}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#666}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc{color:#cdcd00}.highlight-chroma .highlight-kd{color:#00cd00}.highlight-chroma .highlight-kn{color:#cd00cd}.highlight-chroma .highlight-kp,.highlight-chroma .highlight-kr{color:#cdcd00}.highlight-chroma .highlight-kt{color:#00cd00}.highlight-chroma .highlight-nb{color:#cd00cd}.highlight-chroma .highlight-nc{color:#00cdcd}.highlight-chroma .highlight-ne{color:#669;font-weight:700}.highlight-chroma .highlight-nv{color:#00cdcd}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s,.highlight-chroma .highlight-s1,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc,.highlight-chroma .highlight-sd,.highlight-chroma .highlight-se,.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si,.highlight-chroma .highlight-sr,.highlight-chroma .highlight-ss,.highlight-chroma .highlight-sx{color:#cd0000}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#cd00cd}.highlight-chroma .highlight-o{color:#39c}.highlight-chroma .highlight-ow{color:#cdcd00}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm{color:navy}.highlight-chroma .highlight-cs{color:#cd0000;font-weight:700}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:navy}.highlight-chroma .highlight-gd{color:#cd0000}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gr{color:red}.highlight-chroma .highlight-gh{color:navy;font-weight:700}.highlight-chroma .highlight-gi{color:#00cd00}.highlight-chroma .highlight-go{color:#888}.highlight-chroma .highlight-gp{color:navy;font-weight:700}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:purple;font-weight:700}.highlight-chroma .highlight-gt{color:#04d}.highlight-chroma .highlight-gl{text-decoration:underline}.hljs{display:block;overflow-x:auto;padding:.5em;background:#000}.hljs,.hljs-subst,.hljs-tag,.hljs-title{color:#aaa}.hljs-emphasis,.hljs-strong{color:#a8a8a2}.hljs-bullet,.hljs-literal,.hljs-number,.hljs-quote,.hljs-regexp{color:#f5f}.hljs-code .hljs-selector-class{color:#aaf}.hljs-emphasis,.hljs-stronge,.hljs-type{font-style:italic}.hljs-function,.hljs-keyword,.hljs-name,.hljs-section,.hljs-selector-tag,.hljs-symbol{color:#ff5}.hljs-attribute{color:#f55}.hljs-class .hljs-title,.hljs-params,.hljs-variable{color:#88f}.hljs-addition,.hljs-built_in,.hljs-builtin-name,.hljs-link,.hljs-selector-attr,.hljs-selector-id,.hljs-selector-pseudo,.hljs-string,.hljs-template-tag,.hljs-template-variable,.hljs-type{color:#f5f}.hljs-comment,.hljs-deletion,.hljs-meta{color:#5ff}