.highlight-chroma{color:#272822;background-color:#fafafa}.highlight-chroma .highlight-err{color:#960050;background-color:#1e0010}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#e1e1e1}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd{color:#00a8c8}.highlight-chroma .highlight-kn{color:#f92672}.highlight-chroma .highlight-kp,.highlight-chroma .highlight-kr,.highlight-chroma .highlight-kt{color:#00a8c8}.highlight-chroma .highlight-n{color:#111}.highlight-chroma .highlight-na{color:#75af00}.highlight-chroma .highlight-bp,.highlight-chroma .highlight-nb{color:#111}.highlight-chroma .highlight-nc{color:#75af00}.highlight-chroma .highlight-no{color:#00a8c8}.highlight-chroma .highlight-nd{color:#75af00}.highlight-chroma .highlight-ni{color:#111}.highlight-chroma .highlight-ne,.highlight-chroma .highlight-nf{color:#75af00}.highlight-chroma .highlight-fm,.highlight-chroma .highlight-nl,.highlight-chroma .highlight-nn{color:#111}.highlight-chroma .highlight-nx{color:#75af00}.highlight-chroma .highlight-py{color:#111}.highlight-chroma .highlight-nt{color:#f92672}.highlight-chroma .highlight-nv,.highlight-chroma .highlight-vc,.highlight-chroma .highlight-vg,.highlight-chroma .highlight-vi,.highlight-chroma .highlight-vm{color:#111}.highlight-chroma .highlight-l{color:#ae81ff}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-ld,.highlight-chroma .highlight-s,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc,.highlight-chroma .highlight-sd{color:#d88200}.highlight-chroma .highlight-se{color:#8045ff}.highlight-chroma .highlight-s1,.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si,.highlight-chroma .highlight-sr,.highlight-chroma .highlight-ss,.highlight-chroma .highlight-sx{color:#d88200}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#ae81ff}.highlight-chroma .highlight-o,.highlight-chroma .highlight-ow{color:#f92672}.highlight-chroma .highlight-p{color:#111}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm,.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf,.highlight-chroma .highlight-cs{color:#75715e}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gs{font-weight:700}.hljs{display:block;overflow-x:auto;padding:.5em;background:#fbf1c7}.hljs,.hljs-subst{color:#3c3836}.hljs-deletion,.hljs-formula,.hljs-keyword,.hljs-link,.hljs-selector-tag{color:#9d0006}.hljs-built_in,.hljs-emphasis,.hljs-name,.hljs-quote,.hljs-strong,.hljs-title,.hljs-variable{color:#076678}.hljs-attr,.hljs-params,.hljs-template-tag,.hljs-type{color:#b57614}.hljs-builtin-name,.hljs-doctag,.hljs-literal,.hljs-number{color:#8f3f71}.hljs-code,.hljs-meta,.hljs-regexp,.hljs-selector-id,.hljs-template-variable{color:#af3a03}.hljs-addition,.hljs-meta-string,.hljs-section,.hljs-selector-attr,.hljs-selector-class,.hljs-string,.hljs-symbol{color:#79740e}.hljs-attribute,.hljs-bullet,.hljs-class,.hljs-function,.hljs-function .hljs-keyword,.hljs-meta-keyword,.hljs-selector-pseudo,.hljs-tag{color:#427b58}.hljs-comment{color:#928374}.hljs-link_label,.hljs-literal,.hljs-number{color:#8f3f71}.hljs-comment,.hljs-emphasis{font-style:italic}.hljs-section,.hljs-strong,.hljs-tag{font-weight:700}