.highlight-chroma{background-color:#fff}.highlight-chroma .highlight-err{color:red;background-color:#faa}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#e5e5e5}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd,.highlight-chroma .highlight-kn{color:#289;font-weight:700}.highlight-chroma .highlight-kp{color:#08f;font-weight:700}.highlight-chroma .highlight-kr{color:#289;font-weight:700}.highlight-chroma .highlight-kt{color:#66f;font-weight:700}.highlight-chroma .highlight-na{color:#007}.highlight-chroma .highlight-nb{color:#072}.highlight-chroma .highlight-nc{color:#e9e;font-weight:700}.highlight-chroma .highlight-no{color:#5ed;font-weight:700}.highlight-chroma .highlight-nd{color:#555;font-weight:700}.highlight-chroma .highlight-ni{color:#800}.highlight-chroma .highlight-ne{color:red;font-weight:700}.highlight-chroma .highlight-nf{color:#5ed;font-weight:700}.highlight-chroma .highlight-nl{color:#970;font-weight:700}.highlight-chroma .highlight-nn{color:#0e84b5;font-weight:700}.highlight-chroma .highlight-nt{color:#070}.highlight-chroma .highlight-nv{color:#036}.highlight-chroma .highlight-vc{color:#ccf}.highlight-chroma .highlight-vg{color:#f84}.highlight-chroma .highlight-vi{color:#aaf}.highlight-chroma .highlight-s,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb{background-color:#e0e0ff}.highlight-chroma .highlight-sc{color:#88f;background-color:#e0e0ff}.highlight-chroma .highlight-dl{background-color:#e0e0ff}.highlight-chroma .highlight-sd{color:#d42;background-color:#e0e0ff}.highlight-chroma .highlight-s2{background-color:#e0e0ff}.highlight-chroma .highlight-se{color:#666;background-color:#e0e0ff;font-weight:700}.highlight-chroma .highlight-sh{background-color:#e0e0ff}.highlight-chroma .highlight-si{background-color:#eee}.highlight-chroma .highlight-sx{color:#f88;background-color:#e0e0ff}.highlight-chroma .highlight-sr{color:#000;background-color:#e0e0ff}.highlight-chroma .highlight-s1{background-color:#e0e0ff}.highlight-chroma .highlight-ss{color:#fc8;background-color:#e0e0ff}.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf{color:#60e;font-weight:700}.highlight-chroma .highlight-mh{color:#058;font-weight:700}.highlight-chroma .highlight-mi{color:#66f;font-weight:700}.highlight-chroma .highlight-il{color:#60e;font-weight:700}.highlight-chroma .highlight-mo{color:#40e;font-weight:700}.highlight-chroma .highlight-o{color:#333}.highlight-chroma .highlight-ow{color:#000;font-weight:700}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm{color:#666;font-style:italic}.highlight-chroma .highlight-cs{color:#c00;font-weight:700;font-style:italic}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:#579}.highlight-chroma .highlight-gd{color:#a00000}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gr{color:red}.highlight-chroma .highlight-gh{color:navy;font-weight:700}.highlight-chroma .highlight-gi{color:#00a000}.highlight-chroma .highlight-go{color:#888}.highlight-chroma .highlight-gp{color:#c65d09;font-weight:700}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:purple;font-weight:700}.highlight-chroma .highlight-gt{color:#04d}.highlight-chroma .highlight-gl{text-decoration:underline}.highlight-chroma .highlight-w{color:#bbb}.hljs{display:block;overflow-x:auto;padding:.5em;background:#fff}.hljs,.hljs-subst{color:#000}.hljs-addition,.hljs-meta,.hljs-string,.hljs-symbol,.hljs-template-tag,.hljs-template-variable{color:#756bb1}.hljs-comment,.hljs-quote{color:#636363}.hljs-bullet,.hljs-link,.hljs-literal,.hljs-number,.hljs-regexp{color:#31a354}.hljs-deletion,.hljs-variable{color:#88f}.hljs-built_in,.hljs-doctag,.hljs-keyword,.hljs-name,.hljs-section,.hljs-selector-class,.hljs-selector-id,.hljs-selector-tag,.hljs-strong,.hljs-tag,.hljs-title,.hljs-type{color:#3182bd}.hljs-emphasis{font-style:italic}.hljs-attribute{color:#e6550d}